
import {  H4 } from "../components/Headings";
import { LoremMedium } from "../components/Loremipsum";
import { Section, Subesction } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";


export function Results() {
  useTabNavigation();

  return (
    <>
      <Section title="Abstract" id="Abstract">
          <p>We have successfully demonstrated a <b>proof of concept</b> for our gene therapy approach targeting cystic fibrosis. 
            In initial experiments, HEK cells carrying a 3-base deletion analogous to the F508del mutation were transfected 
            with our prime editing complex. The results met our expectations, confirming the viability of our approach for 
            precise gene correction. Based on these findings, we optimized the prime editing complex, leading to the creation 
            of PrimeGuide, a more compact and efficient editing tool. </p>
            <p>Central to our <b>delivery system</b> is <b>AirBuddy</b>, a lung-specific lipid nanoparticle designed to stabilize and protect 
              the prime editing complex during transport to lung ionocytes. AirBuddy ensures that the protein complex is 
              delivered specifically to lung cells, enhancing the efficiency of the gene-editing process. By modifying the 
              lipid nanoparticle with protective features, we achieved increased stability, ensuring effective delivery to the 
              target cells. </p>
              <p>We further optimized the fusion protein, <b>PrimeGuide</b>, to streamline its components, resulting in a smaller and 
                more efficient prime editing complex. This improvement significantly enhances the precision of the gene editing 
                process, reducing off-target effects and increasing the overall success of mutation correction. </p>
          <p>In subsequent experiments, HEK cells carrying the CFTR F508del mutation were successfully transfected with the 
            optimized prime editing complex. Our results indicated successful correction of the mutation, confirming the 
            potential of our approach for treating cystic fibrosis. </p>
          <p>
          Additionally, we explored downstream applications. Primary cell cultures were treated with lipid nanoparticles to 
          introduce a reporter RNA. We also established 2D cultures transfected with YFP, a sodium-sensitive reporter protein, 
          to assess ion channel functionality. Finally, in CFTR-deficient organoids, our system facilitated repair of the CFTR 
          channel, evidenced by an increase in organoid volume upon treatment. This suggests successful functional restoration 
          of CFTR activity. 
          </p>
          <Subesction title="Introduction" id="Abstract1">
            <p>Cystic fibrosis (CF) is a severe genetic disorder caused by mutations in the CFTR gene, most commonly the F508del 
              mutation. This mutation leads to defective ion channels in lung cells, causing mucus buildup, chronic lung infections, 
              and progressive respiratory failure. Current therapies primarily target symptoms, but a definitive cure remains elusive.
              To address this, we aim to develop a targeted gene therapy utilizing prime editing technology. This approach focuses 
              on correcting the CFTR F508del mutation with precision and efficiency. Our innovative system integrates a 
              next-generation prime editing complex (PrimeGuide) with a lung-specific delivery platform (AirBuddy) to achieve 
              targeted and stable delivery to lung ionocytes. </p>
            <p>Our initial proof of concept successfully demonstrated the functionality of the prime editing complex in HEK cells 
              carrying a 3-base deletion analogous to the F508del mutation. Building on these promising results, we optimized the 
              prime editing complex, creating PrimeGuide, a smaller and more effective editing tool. Additionally, we developed 
              AirBuddy, a lung-specific lipid nanoparticle system designed to protect and transport the prime editing complex 
              directly to lung cells. </p>
            <p>This project not only focuses on mutation correction but also validates the gene therapy’s functional restoration 
              in relevant cell models, including primary cultures and organoids. By exploring downstream applications, we aim to 
              offer a promising therapeutic option for cystic fibrosis, potentially paving the way for similar approaches in 
              personalized medicine. </p>
          </Subesction>
          <Subesction title="Goals and Milestones" id="Abstract2">
            <p><b>Develop a gene therapy</b> for cystic fibrosis to correct the CFTR F508del mutation using prime editing technology. </p>
            <p><b>Optimize the prime editing complex</b> (PrimeGuide) to increase efficiency, precision, and reduce off-target effects. </p>
            <p><b>Create a lung-specific delivery system</b> (AirBuddy) for stable and targeted delivery of the prime editing complex to lung ionocytes.</p>
            <p><b>Validate mutation correction</b> in CFTR mutant cells and primary human cultures. </p>
            <p><b>Demonstrate functional recovery</b>of the CFTR channel in treated cells and organoids, confirming the therapeutic potential. </p>
          </Subesction>
      </Section>
      <Section title="Experimental Design" id="Experimental Design">
        <Subesction title="Proof of Concept" id="Experimental Design1">
          <H4 text="acc. to David Liu (Anzalone et al. 2019)"/>
          <LoremMedium/>
        </Subesction>
        <Subesction title="Proof of Concept" id="Experimental Design1">
          <h4>acc. to David Liu (Anzalone et al. 2019)</h4>
          <H4 text="Goals"/>
          <p>Develop a targeted gene therapy for cystic fibrosis using prime editing technology. </p>
          <H4 text="Workflow"/>
          <p></p> 
          <H4 text="Conclusion "/>
          <LoremMedium/>
        </Subesction>
        <Subesction title="PrimeGuide " id="Experimental Design2">
          <H4 text="Goals"/>
          <p>Optimize the prime editing complex (PrimeGuide) for efficient correction of the CFTR F508del mutation. </p>
          <H4 text="Workflow"/>
          <p></p>
          <H4 text="Conclusion "/>
          <LoremMedium/>
        </Subesction>
        <Subesction title="LNP Synthesis " id="Experimental Design3">
          <H4 text="Goals"/>
          <p></p>
          <H4 text="Workflow"/>
          <p></p>
          <H4 text="Conclusion "/>
          <LoremMedium/>
        </Subesction>
        <Subesction title="Cellculture " id="Experimental Design4">
          <H4 text="Goals"/>
          <p></p>
          <H4 text="Workflow"/>
          <p></p>
          <H4 text="Conclusion "/>
          <LoremMedium/>
        </Subesction>
        <Subesction title="Downstream Applications " id="Experimental Design5">
          <H4 text="Goals"/>
          <p></p>
          <H4 text="Workflow"/>
          <p></p>
          <H4 text="Conclusion "/>
          <LoremMedium/>
        </Subesction>
      </Section>
    </>
  );
}
